Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(895)

Unified Diff: components/autofill/core/browser/autofill_metrics.h

Issue 2849753002: Logs all reasons card upload was not offered in UKM and UMA. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_metrics.h
diff --git a/components/autofill/core/browser/autofill_metrics.h b/components/autofill/core/browser/autofill_metrics.h
index 58ab8d26aa06d64471b9fe76613a5405d877f61c..b93a62a884b2a01ccc7b55c19b349573faa8f1e5 100644
--- a/components/autofill/core/browser/autofill_metrics.h
+++ b/components/autofill/core/browser/autofill_metrics.h
@@ -799,12 +799,13 @@ class AutofillMetrics {
// suggestion to show an explanation of the warning.
static void LogShowedHttpNotSecureExplanation();
- // Logs the card upload decision ukm based on the specified |url| and
- // |upload_decision|.
- static void LogCardUploadDecisionUkm(
+ // Logs the card upload decisions ukm based on the specified |url| and
+ // |upload_decisions|.
+ static void LogCardUploadDecisionsUkm(
ukm::UkmService* ukm_service,
const GURL& url,
- AutofillMetrics::CardUploadDecisionMetric upload_decision);
+ const std::vector<AutofillMetrics::CardUploadDecisionMetric>&
+ upload_decisions);
// Logs the developer engagement ukm for the specified |url| and autofill
// fields in the form structure.

Powered by Google App Engine
This is Rietveld 408576698